@@ -821,7 +821,7 @@ gnetwork_interface_info_collate (const GNetworkInterfaceInfo * info1,
 }
 
 
-GNetworkProtocols
+/* GNetworkProtocols
 gnetwork_str_to_protocol (const gchar * address)
 {
   GNetworkProtocols retval;
@@ -843,4 +843,4 @@ gnetwork_str_to_protocol (const gchar * address)
   g_free (ptr);
 
   return retval;
-}
+} */
