@@ -278,7 +278,7 @@ gnetwork_tcp_connection_close (GNetworkTcpConnection * connection)
       g_free (item->data);
       g_free (item);
 
-      connection->_priv->buffer = g_slist_remove_link (connection->_priv->buffer,
+      connection->_priv->buffer = g_slist_delete_link (connection->_priv->buffer,
 						       connection->_priv->buffer);
     }
 
@@ -394,14 +394,15 @@ io_channel_handler (GIOChannel * channel, GIOCondition cond, GNetworkTcpConnecti
 		    {
 		      BufferItem *new_item = g_new0 (BufferItem, 1);
 
-		      new_item->data = g_new (guchar, item->length - bytes_sent + 1);
-		      memcpy (new_item->data, G_UCHAR (item->data) + bytes_sent, new_item->length);
 		      new_item->length = item->length - bytes_sent;
+		      new_item->data = g_new (guchar, new_item->length + 1);
+		      memcpy (new_item->data, G_UCHAR (item->data) + bytes_sent,
+			      new_item->length);
 		      connection->_priv->buffer->data = new_item;
 		    }
 		  else
 		    {
-		      connection->_priv->buffer = g_slist_remove_link (connection->_priv->buffer,
+		      connection->_priv->buffer = g_slist_delete_link (connection->_priv->buffer,
 								       connection->_priv->buffer);
 		    }
 		}
@@ -1283,7 +1284,7 @@ gnetwork_tcp_connection_dispose (GObject * object)
   GNetworkTcpConnection *connection = GNETWORK_TCP_CONNECTION (object);
 
   if (connection->_priv->tcp_status > GNETWORK_TCP_CONNECTION_CLOSED)
-    gnetwork_tcp_connection_close (connection);
+    gnetwork_connection_close (connection);
 
   if (G_OBJECT_CLASS (parent_class)->dispose)
     (*G_OBJECT_CLASS (parent_class)->dispose) (object);
@@ -1312,30 +1313,6 @@ gnetwork_tcp_connection_finalize (GObject * object)
  *  GType Functions  *
  * ***************** */
 
-static void
-gnetwork_tcp_connection_base_init (gpointer class)
-{
-#if 0
-#ifdef _USE_SSL
-  _gnetwork_ssl_initialize ();
-#endif /* _USE_SSL */
-#endif /* 0 */
-  _gnetwork_tcp_proxy_initialize ();
-}
-
-
-static void
-gnetwork_tcp_connection_base_finalize (gpointer class)
-{
-#if 0
-#ifdef _USE_SSL
-  _gnetwork_ssl_shutdown ();
-#endif /* _USE_SSL */
-#endif /* 0 */
-  _gnetwork_tcp_proxy_shutdown ();
-}
-
-
 static void
 gnetwork_tcp_connection_class_init (GNetworkTcpConnectionClass * class)
 {
@@ -1436,6 +1413,13 @@ gnetwork_tcp_connection_class_init (GNetworkTcpConnectionClass * class)
 		  G_STRUCT_OFFSET (GNetworkTcpConnectionClass, certificate_error),
 		  NULL, NULL, _gnetwork_marshal_VOID__BOXED_FLAGS,
 		  G_TYPE_NONE, 2, GNETWORK_TYPE_SSL_CERT, GNETWORK_TYPE_SSL_CERT_ERROR_FLAGS);
+
+#if 0
+#ifdef _USE_SSL
+  _gnetwork_ssl_initialize ();
+#endif /* _USE_SSL */
+#endif /* 0 */
+  _gnetwork_tcp_proxy_initialize ();
 }
 
 
@@ -1488,8 +1472,8 @@ gnetwork_tcp_connection_get_type (void)
     {
       static const GTypeInfo info = {
 	sizeof (GNetworkTcpConnectionClass),
-	(GBaseInitFunc) gnetwork_tcp_connection_base_init,
-	(GBaseFinalizeFunc) gnetwork_tcp_connection_base_finalize,
+	(GBaseInitFunc) NULL,
+	(GBaseFinalizeFunc) NULL,
 	(GClassInitFunc) gnetwork_tcp_connection_class_init,
 	(GClassFinalizeFunc) NULL,
 	NULL,			/* class data */
