@@ -315,7 +315,7 @@ io_channel_handler (GIOChannel * channel, GIOCondition cond, GNetworkUnixConnect
 		    }
 		  else
 		    {
-		      connection->_priv->buffer = g_slist_remove_link (connection->_priv->buffer,
+		      connection->_priv->buffer = g_slist_delete_link (connection->_priv->buffer,
 								       connection->_priv->buffer);
 		    }
 		}
